@@ -25,8 +25,8 @@ def mapToRef(out_dir):
                     mkdir(sitePath)
                     bashFile.write( f'''bwa mem -R \'@RG\\tID:hpv\\tSM:hpv\\tLB:hpv\\tPL:ILLUMINA\' -M -t 8 \
 {newRef} {contigPath}/{site}.all.fa.cap.contigs > {sitePath}/{site}.contig.sam;
-samtools view -bhS -@ 8 {sitePath}/{site}.contig.sam > {sitePath}/{site}.contig.bam;
-samtools sort -@ 8 -o {sitePath}/{site}.contig.sort.bam {sitePath}/{site}.contig.bam;
+samtools view -bhS {sitePath}/{site}.contig.sam > {sitePath}/{site}.contig.bam;
+samtools sort -o {sitePath}/{site}.contig.sort.bam {sitePath}/{site}.contig.bam;
 samtools index {sitePath}/{site}.contig.sort.bam;
 rm {sitePath}/{site}.contig.bam;\n''')
     return f'{outputPath}/alignContigsToRef.sh'
@@ -55,8 +55,8 @@ def mapToHgRef(out_dir,humRef):
                     mkdir(sitePath)
                     bashFile.write( f'''bwa mem -R \'@RG\\tID:hpv\\tSM:hpv\\tLB:hpv\\tPL:ILLUMINA\' -M -t 8 \
 {humRef} {contigPath}/{site}.all.fa.cap.contigs > {sitePath}/{site}.contigToGenome.sam;
-samtools view -bhS -@ 8 {sitePath}/{site}.contigToGenome.sam > {sitePath}/{site}.contigToGenome.bam;
-samtools sort -@ 8 -o {sitePath}/{site}.contigToGenome.sort.bam {sitePath}/{site}.contigToGenome.bam;
+samtools view -bhS {sitePath}/{site}.contigToGenome.sam > {sitePath}/{site}.contigToGenome.bam;
+samtools sort -o {sitePath}/{site}.contigToGenome.sort.bam {sitePath}/{site}.contigToGenome.bam;
 samtools index {sitePath}/{site}.contigToGenome.sort.bam;
 rm {sitePath}/{site}.contigToGenome.bam;\n''')
     return f'{outputPath}/alignContigsToGenome.sh'
@@ -81,8 +81,8 @@ def mapToVirRef(out_dir,virRef):
                     sitePath = f'{out_dir}/call_fusion_virus/{site}/'
                     bashFile.write( f'''bwa mem -R \'@RG\\tID:hpv\\tSM:hpv\\tLB:hpv\\tPL:ILLUMINA\' -M -t 8 \
 {virRef} {contigPath}/{site}.all.fa.cap.contigs > {contigPath}/{site}.contigToVirus.sam;
-samtools view -bhS -@ 8 {contigPath}/{site}.contigToVirus.sam >  {contigPath}/{site}.contigToVirus.bam;
-samtools sort -@ 8 -o {sitePath}/{site}.contigToVirus.sort.bam {contigPath}/{site}.contigToVirus.bam;
+samtools view -bhS {contigPath}/{site}.contigToVirus.sam >  {contigPath}/{site}.contigToVirus.bam;
+samtools sort -o {sitePath}/{site}.contigToVirus.sort.bam {contigPath}/{site}.contigToVirus.bam;
 samtools index {sitePath}/{site}.contigToVirus.sort.bam;
 samtools faidx {contigPath}/{site}.all.fa.cap.contigs;
 rm {contigPath}/{site}.contigToVirus.bam;\n''')
